==> react-list-masonry-1.7.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import PropTypes from 'prop-types';
import React from 'react';
import cx from 'classnames';
var DEFAULT_COLS = 1;

var ListMasonry =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(ListMasonry, _React$Component);

  function ListMasonry() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;
    _this.state = {
      columns: DEFAULT_COLS
    };

    _this._onResize = function (_ref) {
      var _ref$firstResize = _ref.firstResize,
          firstResize = _ref$firstResize === void 0 ? false : _ref$firstResize;
      var _this$props = _this.props,
          onColumnsReady = _this$props.onColumnsReady,
          onColumnsUpdated = _this$props.onColumnsUpdated;

      var columns = _this._getColumns(_this.listMasonry.offsetWidth);

      if (columns !== _this.state.columns) {
        _this.setState({
          columns: columns
        }, function () {
          if (firstResize) {
            onColumnsReady();
          } else {
            onColumnsUpdated();
          }
        });
      }
    };

    return _this;
  }

  var _proto = ListMasonry.prototype;

  _proto.componentDidMount = function componentDidMount() {
    this._onResize({
      firstResize: true
    });

    window.addEventListener('resize', this._onResize);
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    window.removeEventListener('resize', this._onResize);
  };

  _proto._getColumns = function _getColumns(width) {
    return this.props.breakPoints.reduceRight(function (collector, current, index) {
      return current < width ? collector : index;
    }, this.props.breakPoints.length) + 1;
  };

  _proto._mapChildren = function _mapChildren() {
    var col = [];
    var numColumns = this.state.columns;

    for (var i = 0; i < numColumns; i++) {
      col.push([]);
    }

    return this.props.children.reduce(function (collector, current, index) {
      collector[index % numColumns].push(current);
      return collector;
    }, col);
  };

  _proto.render = function render() {
    var _this2 = this;

    var masonryClassName = cx('sui-ListMasonry', this.props.className);
    return React.createElement("div", {
      className: masonryClassName,
      ref: function ref(node) {
        return _this2.listMasonry = node;
      }
    }, this._mapChildren().map(function (col, columnIndex) {
      return React.createElement("div", {
        className: "sui-ListMasonry-column",
        key: columnIndex
      }, col.map(function (child, index) {
        return React.createElement("div", {
          key: index
        }, child);
      }));
    }));
  };

  return ListMasonry;
}(React.Component);

export default ListMasonry;
ListMasonry.displayName = 'ListMasonry';
ListMasonry.defaultProps = {
  onColumnsReady: function onColumnsReady() {},
  onColumnsUpdated: function onColumnsUpdated() {}
};

==> react-list-masonry-1.9.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import { Component } from 'react';
import cx from 'classnames';
var DEFAULT_COLS = 1;

var ListMasonry = /*#__PURE__*/function (_Component) {
  _inheritsLoose(ListMasonry, _Component);

  function ListMasonry() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      columns: DEFAULT_COLS
    };

    _this._onResize = function (_ref) {
      var _ref$firstResize = _ref.firstResize,
          firstResize = _ref$firstResize === void 0 ? false : _ref$firstResize;
      var _this$props = _this.props,
          onColumnsReady = _this$props.onColumnsReady,
          onColumnsUpdated = _this$props.onColumnsUpdated;

      var columns = _this._getColumns(_this.listMasonry.offsetWidth);

      if (columns !== _this.state.columns) {
        _this.setState({
          columns: columns
        }, function () {
          if (firstResize) {
            onColumnsReady();
          } else {
            onColumnsUpdated();
          }
        });
      }
    };

    return _this;
  }

  var _proto = ListMasonry.prototype;

  _proto.componentDidMount = function componentDidMount() {
    this._onResize({
      firstResize: true
    });

    window.addEventListener('resize', this._onResize);
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    window.removeEventListener('resize', this._onResize);
  };

  _proto._getColumns = function _getColumns(width) {
    return this.props.breakPoints.reduceRight(function (collector, current, index) {
      return current < width ? collector : index;
    }, this.props.breakPoints.length) + 1;
  };

  _proto._mapChildren = function _mapChildren() {
    var col = [];
    var numColumns = this.state.columns;

    for (var i = 0; i < numColumns; i++) {
      col.push([]);
    }

    return this.props.children.reduce(function (collector, current, index) {
      collector[index % numColumns].push(current);
      return collector;
    }, col);
  };

  _proto.render = function render() {
    var _this2 = this;

    var masonryClassName = cx('sui-ListMasonry', this.props.className);
    return /*#__PURE__*/_jsx("div", {
      className: masonryClassName,
      ref: function ref(node) {
        return _this2.listMasonry = node;
      },
      children: this._mapChildren().map(function (col, columnIndex) {
        return /*#__PURE__*/_jsx("div", {
          className: "sui-ListMasonry-column",
          children: col.map(function (child, index) {
            return /*#__PURE__*/_jsx("div", {
              children: child
            }, index);
          })
        }, columnIndex);
      })
    });
  };

  return ListMasonry;
}(Component);

export default ListMasonry;
ListMasonry.displayName = 'ListMasonry';
ListMasonry.defaultProps = {
  onColumnsReady: function onColumnsReady() {},
  onColumnsUpdated: function onColumnsUpdated() {}
};
